==> openGion6.4.0.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF74S.sql <==
/****************************************************************************/
/* GF74 ( QUERY状態ﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2015/11/16 16:20:03                                            */
/****************************************************************************/
CREATE TABLE GF74 (
   SYSTEM_ID    VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR2 (    1 )                   NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , ADDRESS      VARCHAR2 (  256 )                                       /*  30 ｱﾄﾞﾚｽ        */
 , FILENAME     VARCHAR2 (   60 )                                       /*  40 ﾌｧｲﾙ名       */
 , FILEPATH     VARCHAR2 (  256 )                                       /*  50 ﾌｧｲﾙﾊﾟｽ      */
 , MODIFIED     VARCHAR2 (   14 )                                       /*  60 最終更新日   */
 , TAGNAME      VARCHAR2 (   30 )                                       /*  80 ﾀｸﾞ名称      */
 , CLMS         VARCHAR2 ( 4000 )                                       /*  90 ｶﾗﾑ一覧      */
 , TABLEID      VARCHAR2 (   50 )                                       /* 100 ﾃｰﾌﾞﾙID      */
 , JSP_SCOPE    VARCHAR2 (   20 )                                       /* 110 ｽｺｰﾌﾟ        */
 , TABLE_NAMES  VARCHAR2 ( 4000 )                                       /* 110 ﾃｰﾌﾞﾙ一覧    */
 , DBID         VARCHAR2 (   20 )                                       /* 110 ﾃﾞｰﾀﾍﾞｰｽID   */
 , FGOMIT       VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /* 110 除外ﾌﾗｸﾞ     */
 , SQL_TEXT     CLOB                                                    /* 110 検索         */
 , SQL_TYPE     VARCHAR2 (   30 )                                       /* 110 ｸｴﾘｰﾀｲﾌﾟ     */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成社員     */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GF74S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF74T00 
  BEFORE INSERT ON GF74
  FOR EACH ROW 
  BEGIN 
    SELECT GF74S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion6.4.1.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF74S.sql <==
/****************************************************************************/
/* GF74 ( QUERY状態ﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2016/01/07 17:07:19                                            */
/****************************************************************************/
CREATE TABLE GF74 (
   SYSTEM_ID    VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR2 (    1 )                   NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , ADDRESS      VARCHAR2 (  256 )                                       /*  30 ｱﾄﾞﾚｽ        */
 , FILENAME     VARCHAR2 (   60 )                                       /*  40 ﾌｧｲﾙ名       */
 , FILEPATH     VARCHAR2 (  256 )                                       /*  50 ﾌｧｲﾙﾊﾟｽ      */
 , MODIFIED     VARCHAR2 (   14 )                                       /*  60 最終更新日   */
 , TAGNAME      VARCHAR2 (   30 )                                       /*  80 ﾀｸﾞ名称      */
 , CLMS         VARCHAR2 ( 4000 )                                       /*  90 ｶﾗﾑ一覧      */
 , TABLEID      VARCHAR2 (   50 )                                       /* 100 ﾃｰﾌﾞﾙID      */
 , DBID         VARCHAR2 (   20 )                                       /* 110 ﾃﾞｰﾀﾍﾞｰｽID   */
 , FGOMIT       VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /* 110 除外ﾌﾗｸﾞ     */
 , JSP_SCOPE    VARCHAR2 (   20 )                                       /* 110 ｽｺｰﾌﾟ        */
 , SQL_TEXT     CLOB                                                    /* 110 検索         */
 , SQL_TYPE     VARCHAR2 (   30 )                                       /* 110 ｸｴﾘｰﾀｲﾌﾟ     */
 , TABLE_NAMES  VARCHAR2 ( 4000 )                                       /* 110 ﾃｰﾌﾞﾙ一覧    */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成社員     */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

CREATE SEQUENCE GF74S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF74T00 
  BEFORE INSERT ON GF74
  FOR EACH ROW 
  BEGIN 
    SELECT GF74S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
